#!/bin/bash

# Check if a target directory path is provided
if [ "$#" -ne 1 ]; then
    echo "Usage: $0 <target_directory>"
    exit 1
fi

TARGET_DIR="$1"

# Name of the script
SCRIPT_NAME=$(basename "$0")

# Directory where the script is located
SCRIPT_DIR=$(dirname "$(readlink -f "$0")")

# Check if the target directory exists
if [ ! -d "$TARGET_DIR" ]; then
    echo "Target directory does not exist: $TARGET_DIR"
    exit 1
fi

# Check if the 'ai' file exists in the target directory
if [ ! -f "$TARGET_DIR/ai" ]; then
    echo "The required 'ai' file is not present in $TARGET_DIR"
    exit 1
fi

echo "Starting to move files from $SCRIPT_DIR to $TARGET_DIR..."

# Move all contents from the script's directory to the target directory, excluding the script
rsync -av --remove-source-files --exclude="$SCRIPT_NAME" "$SCRIPT_DIR/" "$TARGET_DIR"

# Remove the 'tmp' directory, assuming it's a subdirectory of the script's location
echo "Deleting the 'tmp' directory..."
rm -rf "$TARGET_DIR/tmp"

chmod +x "$TARGET_DIR/ai"

echo "Update complete"
